# Pretty Genetic Algorithm

The pretty genetic algorithm project contains a genetic algorithm class which will provide pretty progress updates as well as many different options for how you want to implement a genetic algorithm.
